@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt.c,v 1.15 2001/11/07 12:04:19 nmav Exp $ */
+/* $Id: mcrypt.c,v 1.16 2001/12/15 11:27:34 nmav Exp $ */
 
 /* Changed by Steve Underwood 1999/12/10 to allow an arbitrary number of 
  * streams of encryption. Currently the resulting code is probably not
@@ -54,7 +54,7 @@ static int internal_end_mcrypt(MCRYPT td);
 
 static int internal_init_mcrypt(MCRYPT td, void *key, int lenofkey, void *IV)
 {
-	const int *sizes = NULL;
+	int *sizes = NULL;
 	int num_of_sizes, i, ok = 0;
 	int key_size = mcrypt_enc_get_key_size(td);
 
