@@ -219,7 +219,6 @@ MCRYPT mcrypt_module_open(char *algorithm,
 	if (mcrypt_enc_is_block_algorithm_mode(td) !=
 	    mcrypt_enc_is_block_algorithm(td)) {
 		mcrypt_module_close(td);
-		free(td);
 		return MCRYPT_FAILED;
 	}
 
@@ -440,7 +439,7 @@ char *mcrypt_enc_get_algorithms_name(MCRYPT td)
 		return NULL;
 	}
 
-	return strdup(_mcrypt_get_algorithms_name());
+	return (char*) strdup(_mcrypt_get_algorithms_name());
 }
 
 WIN32DLL_DEFINE
@@ -517,7 +516,7 @@ char *mcrypt_enc_get_modes_name(MCRYPT td)
 		return NULL;
 	}
 
-	return strdup(_mcrypt_get_modes_name());
+	return (char*) strdup(_mcrypt_get_modes_name());
 }
 
 WIN32DLL_DEFINE
